package com.yyxx.eyuancomm.demo

import android.content.Context
import android.text.TextUtils
import org.json.JSONException
import org.json.JSONObject

/**
 * @author #Suyghur.
 * Created on 2020/12/7
 */
class CacheRoleInfo {
    data class RoleInfo(
        var roleId: String = "", var roleName: String = "", var roleLevel: String = "",
        var rolePower: Int = 0, var roleGold: Int = 0, var roleChange: Int = 0,
        var serverCode: String = "", var serverName: String = "", var vipLevel: String = "",
        var partyId: String = "", var partyName: String = "", var roleCTime: Long = 0
    ) {
        fun toJsonString(): String {
            val jsonObject = JSONObject()
            try {
                jsonObject.put("role_id", roleId)
                jsonObject.put("role_name", roleName)
                jsonObject.put("role_level", roleLevel)
                jsonObject.put("role_power", rolePower)
                jsonObject.put("role_gold", roleGold)
                jsonObject.put("role_change", roleChange)
                jsonObject.put("role_ctime", roleCTime)
                jsonObject.put("party_id", partyId)
                jsonObject.put("party_name", partyName)
                jsonObject.put("server_code", serverCode)
                jsonObject.put("server_name", serverName)
                jsonObject.put("vip_level", vipLevel)
                return jsonObject.toString()
            } catch (e: Exception) {
                e.printStackTrace()
            }
            return ""
        }
    }

    companion object {

        @JvmStatic
        fun setDemoRoleInfo(context: Context, userId: String): RoleInfo {
            val ts = System.currentTimeMillis() / 1000
            val roleInfo = RoleInfo(
                roleId = "aaa$ts",
                roleName = "角色名123",
                roleLevel = "110",
                rolePower = 100,
                roleGold = 100,
                roleChange = 100,
                serverCode = "333",
                serverName = "服务器名333",
                vipLevel = "1",
                roleCTime = ts,
                partyId = "party_101",
                partyName = "帮派名"
            )
            val info = roleInfo.toJsonString()
            val sp = context.getSharedPreferences("app_role_info", Context.MODE_PRIVATE)
            val editor = sp.edit()
            editor.putString(userId, info)
            editor.apply()
            return roleInfo
        }

        @JvmStatic
        fun getDemoRoleInfo(context: Context, userId: String): RoleInfo? {
            try {
                val sp = context.getSharedPreferences("app_role_info", Context.MODE_PRIVATE)
                val info = sp.getString(userId, "")
                return if (TextUtils.isEmpty(info)) {
                    //没有则创建
                    setDemoRoleInfo(context, userId)
                } else {
                    val jsonObject = JSONObject(info!!)
                    RoleInfo(
                        roleId = jsonObject.getString("role_id"),
                        roleName = jsonObject.getString("role_name"),
                        roleLevel = jsonObject.getString("role_level"),
                        serverCode = jsonObject.getString("server_code"),
                        serverName = jsonObject.getString("server_name"),
                        vipLevel = jsonObject.getString("vip_level"),
                        partyId = jsonObject.getString("party_id"),
                        partyName = jsonObject.getString("party_name"),
                        roleCTime = jsonObject.getLong("role_ctime"),
                        rolePower = jsonObject.getInt("role_power"),
                        roleGold = jsonObject.getInt("role_gold"),
                        roleChange = jsonObject.getInt("role_change")
                    )
                }

            } catch (e: Exception) {
                e.printStackTrace()
            }
            return null
        }
    }
}